@@ -12,8 +12,13 @@ if 'reversion' in settings.INSTALLED_APPS:
 class TermAdmin(ModelAdmin):
     model = Term
     form = TermForm
-    list_display = ('name', 'url')
+    list_display = ('__str__', 'name', 'url', 'case_sensitive')
+    list_editable = ('name', 'url', 'case_sensitive')
     search_fields = ('name', 'definition', 'url')
 
+    def get_changelist_form(self, request, **kwargs):
+        kwargs['form'] = self.form
+        return super(TermAdmin, self).get_changelist_form(request, **kwargs)
+
 
 site.register(Term, TermAdmin)
