@@ -1,4 +1,5 @@
 from django.contrib.sitemaps import Sitemap
+from django.db.models import Q
 from .models import Term
 
 
@@ -7,4 +8,4 @@ class TermsSitemap(Sitemap):
     priority = 0.1
 
     def items(self):
-        return Term.objects.all()
+        return Term.objects.filter(Q(url__startswith='/') | Q(url=''))
